@@ -1,4 +1,5 @@
 #!/bin/bash
+MODE=${1:-double}
 
 cnfpath=`realpath ../conf/node_mgr.cnf`
 source ./extra.env
@@ -10,7 +11,11 @@ num=`ps -ef | grep ${cnfpath} | grep -v grep | grep -v vim | wc -l`
 }
 
 if test "$USE_VALGRIND" = ""; then
-	./node_mgr ${cnfpath} >../log/std.log 2>&1
+	if [ ${MODE} == "single" ]; then
+		./node_mgr ${cnfpath} ${MODE} >../log/std.log 2>&1 &
+	else
+		./node_mgr ${cnfpath} >../log/std.log 2>&1
+	fi
 else
 	valgrind --leak-check=full --undef-value-errors=no ./node_mgr ${cnfpath} >../log/std.log 2>&1
 fi
@@ -18,4 +23,4 @@ fi
 # sleep 5 seconds to let the process appear in ps command, for busy machines.
 sleep 5
 
-ps -ef | grep ${cnfpath} | grep -v grep
+ps --sort=start_time -ef | grep ${cnfpath} | grep -v grep | awk '{print $2}' | head -1 > nodemgr.pid
